# SciREX

**ACL 2020**: [SciREX: A Challenge Dataset for Document-Level Information Extraction](https://aclanthology.org/2020.acl-main.670/)

**GitHub**: [`allenai/SciREX`](https://github.com/allenai/SciREX)
